@@ -44,9 +44,10 @@ taskscheduler_ls <- function(...){
 #' @param startdate a date that specifies the first date on which to run the task.
 #' Only applicable if schedule is of type 'MONTHLY', 'WEEKLY', 'DAILY', 'HOURLY', 'MINUTE'. Defaults to today in '\%d/\%m/\%Y' format. Change to your locale format if needed.
 #' @param days character string with days on which to run the script if schedule is 'WEEKLY' or 'MONTHLY'. Possible values
-#' are * (all days), 'MON', 'TUE', 'WED', 'THU', 'FRI', 'SAT', 'SUN', 1:31.
+#' are * (all days). For weekly: 'MON', 'TUE', 'WED', 'THU', 'FRI', 'SAT', 'SUN' or a vector of these in your locale.
+#' For monthly: 1:31 or a vector of these.
 #' @param months character string with months on which to run the script if schedule is 'MONTHLY'. Possible values
-#' are * (all months), 'JAN', 'FEB', 'MAR', 'APR', 'MAY', 'JUN', 'JUL', 'AUG', 'SEP', 'OCT', 'NOV', 'DEC'.
+#' are * (all months) or 'JAN', 'FEB', 'MAR', 'APR', 'MAY', 'JUN', 'JUL', 'AUG', 'SEP', 'OCT', 'NOV', 'DEC' or a vector of these in your locale.
 #' @param modifier a modifier to apply. See the docs/schtasks.pdf
 #' @param idletime integer containing a value that specifies the amount of idle time to wait before 
 #' running a scheduled ONIDLE task. The valid range is 1 - 999 minutes.
@@ -120,8 +121,17 @@ taskscheduler_create <- function(taskname = basename(rscript),
     warning("Filename does not include the full path, provide %s as full path including the directory", task)
   }
   schedule <- match.arg(schedule)
-  days <- match.arg(days)
-  months <- match.arg(months)
+  if("*" %in% days){
+    days <- "*"
+  }else{
+    days <- paste(days, collapse = ",")
+  }
+  if("*" %in% months){
+    months <- "*"
+  }else{
+    months <- paste(months, collapse = ",")
+  }
+  
   
   taskname <- force(taskname)
   if(length(grep(" ", taskname)) > 0){
